#include "TFile.h"
#include "TTree.h"
#include "TLegend.h"

//#define __NDIV          8
//#define __THICKNESS 0.320 // [mm]  KEK FE-I3
#define __THICKNESS 0.150 // [mm]    KEK FE-I4 run 50734 to 50744

#define __CHARGE  10
#define __ENTRIES 20

void runNewAlgo(){

	gROOT->ProcessLine(".x ~/styles/AtlasStyle.C");

	TChain * T1 = new TChain("ShallowAngleFEIX");
	T1->Add("/storage1/idarraga/Testbeam_July_CERN_2011/KEK_100V_4deg/MAFOutput/MAFOutput_MPXNtuple_USBPIXI4_20_100V.root");
	TString titleT = "KEK FE-I4 ~4deg DUT3";
	//T1->Add("/home/idarraga/analysis/mafalda/MAFOutput_MPXNtuple_USBPIX_10_dep.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050620.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050621.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050622.root");

	Int_t plotType = __CHARGE;
	Int_t ndiv = 10;
	Int_t fulldiv = 10;
	Int_t rangeYMax = 14;

	TCanvas * c10 = new TCanvas();

	TGraphErrors * g1 = GetGraph(T1, "V100V", ndiv, fulldiv, plotType);
	c10->cd();
	g1->Draw("A*");
	g1->GetXaxis()->SetTitle("depth [mm]");
	g1->GetYaxis()->SetTitle("Q [TOT]");
	g1->GetYaxis()->SetRangeUser(0., rangeYMax);
	g1->SetMarkerStyle(26);
	g1->SetMarkerSize(2.0);
	g1->SetMarkerColor(kBlue);

	TLatex * lt1 = new TLatex();
	lt1->DrawLatex(0.050, 9, "backside");
	lt1->DrawLatex(0.050, 13, "frontside");
	lt1->DrawLatex(0.06, 4, titleT);

	TLatex * lt2 = new TLatex();
	lt2->SetTextSize(0.03);
	lt2->DrawLatex(0.06, 1, "MAFalda, idarraga@cern.ch");

	/////////////////////////////////////////////////////////////////////////////////////

	TChain * T2 = new TChain("ShallowAngleFEIX");
	T2->Add("/storage1/idarraga/Testbeam_July_CERN_2011/KEK_15V_4deg/MAFOutput/MAFOutput_MPXNtuple_USBPIXI4_21_15V.root");

	TGraphErrors * g2 = GetGraph(T2, "15V", 9, fulldiv, plotType);
	// fix last point
	c10->cd();
	g2->Draw("*");
	g2->SetMarkerStyle(21);
	g2->SetMarkerColor(kRed);

	/////////////////////////////////////////////////////////////////////////////////////

	TChain * T3 = new TChain("ShallowAngleFEIX");
	T3->Add("/storage1/idarraga/Testbeam_July_CERN_2011/KEK_7V_4deg/MAFOutput/MAFOutput_MPXNtuple_USBPIXI4_21_7V.root");

	TGraphErrors * g3 = GetGraph(T3, "7V", 9, fulldiv, plotType);
	// fix last point
	c10->cd();
	g3->Draw("*");
	g3->SetMarkerStyle(20);
	g3->SetMarkerColor(kGreen);

	/////////////////////////////////////////////////////////////////////////////////////
	TLegend * l1 = new TLegend(0.5, 0.7, 0.9, 0.9);
	l1->AddEntry(g1, "100V run50734", "P");
	l1->AddEntry(g2, "15V run50739", "P");
	l1->AddEntry(g3, "7V run50743", "P");
	l1->Draw();
	l1->SetBorderSize(1);
	l1->SetFillColor(kWhite);


}

TGraphErrors * GetGraph(TChain * T, TString sufx, Int_t __NDIV, Int_t fullDiv, Int_t graphType){

	gROOT->ProcessLine(".x ~/styles/AtlasStyle.C");

	//TChain * T = new TChain("ShallowAngleFEIX");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_MPXNtuple_USBPIX_10.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050620.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050621.root");
	//T->Add("/home/idarraga/analysis/mafalda/MAFOutput_KEK_run050622.root");
	cout << "Entries = " << T->GetEntries() << endl;

	TCanvas * c1 = new TCanvas("c_"+sufx, "c_"+sufx);
	c1->Divide(__NDIV/2  + 1 , 2);

	vector<double> depth;
	vector<double> errDepth;
	vector<double> Qp;
	vector<double> errQp;

	vector<double> entriesV;

	double maxQp = 0;

	cout << "Drawing" << endl;
	TString wordDraw = "";
	TString histo = "";
	double partition = double(__THICKNESS)/double(fullDiv);

	int partitionCntr = 0;
	//for (indx = __NDIV-1 ; indx >= 0 ; indx--) {
	for (indx = 0 ; indx < __NDIV ; indx++) {

		wordDraw = "totPerSegment[";
		wordDraw += indx;
		wordDraw += "]>>h_";
		wordDraw += sufx;
		wordDraw += "_";
		wordDraw += indx;
		wordDraw += "(20, 0, 20)";

		histo = "h_";
		histo += sufx;
		histo += "_";
		histo += indx;

		cout << "word --> " << wordDraw << endl;
		c1->cd(indx+1);
		TString cutS = "clusterHeight < 3 && ";
		cutS += "clusterSize == ";
		cutS += __NDIV;
		TCut cutC = cutS;
		T->Draw(wordDraw, cutC);
		//"nDeltaRaySoft == 0 && nDeltaRayExplicit == 0");
		//T->Draw(wordDraw, "nDeltaRayExplicit == 0");
		TH1F * h = gROOT->FindObject(histo);
		h->GetXaxis()->SetTitle("TOT");
		h->GetXaxis()->SetTitleSize(0.15);
		h->GetXaxis()->SetTitleOffset(0.5);
		h->GetXaxis()->SetLabelSize(0.06);


		double meanQp = h->GetMean();
		double errQpValue = h->GetMeanError();
		cout << "mean = " << meanQp << " err = " << errQpValue << endl;

		///////////////////////////////////////////////////////
		TLatex * Tl = new TLatex;
		Tl->SetTextAlign(12);
		Tl->SetTextSize(0.15);
		TString a = "[";
		a += indx; a += "]=";
		a +	= TString::Format("%.1f", meanQp);
		Tl->DrawLatex(meanQp, h->GetMaximum()*0.9, a);

		TLatex * Tb = new TLatex;
		Tb->SetTextAlign(12);
		Tb->SetTextSize(0.15);
		Int_t nentries = h->GetEntries();
		cout << "entries in histo = " << nentries << endl;
		TString b1 = "ent ";
		entriesV.push_back( nentries );
		b1 +	= TString::Format("%d", nentries);
		Tb->DrawLatex(meanQp*0.5, h->GetMaximum()/3., b1);

		// for final plot
		Qp.push_back(meanQp);
		//Qp.push_back(div[indx]);
		//cout << "div index = " << div[indx] << endl;
		errQp.push_back(errQpValue);
		depth.push_back(partitionCntr*partition + (partition/2.));
		errDepth.push_back(partition/2.);
		if(meanQp > maxQp) maxQp = meanQp; // keep the max


		partitionCntr++;
	}


	if ( __NDIV == 6 ) {
		Qp.push_back(0.);
		errQp.push_back(0.);
		depth.push_back( partitionCntr*partition + (partition/2.) );
		errDepth.push_back(partition/2.);
	}

	TCanvas * c2 = new TCanvas();
	c2->cd();

	TGraphErrors * g;
	if(graphType == __CHARGE){
		g = new TGraphErrors((int)Qp.size(), &depth[0], &Qp[0], &errDepth[0], &errQp[0]);
	}
	else if(graphType == __ENTRIES){
		g = new TGraphErrors((int)Qp.size(), &depth[0], &entriesV[0], 0x0, 0x0);
	}


	return g;
}
